Community
=========
Learn how to contribute to the project and how you can become part of the community
of content developers working to integrate content into the Kolibri platform,
and more broadly into all offline learning tools.

.. toctree::
   :maxdepth: 1

   contributing
   authors
   ../history

.. TODOC: volunteers progam, step-by-step guide to small contribution, etc.
